#
# spec file for package python-langfuse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-langfuse
Version:        2.54.1
Release:        1.2
Summary:        A client library for accessing langfuse
License:        MIT
URL:            https://github.com/langfuse/langfuse-python
Source:         https://files.pythonhosted.org/packages/source/l/langfuse/langfuse-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-anyio
Requires:       python-backoff
Requires:       python-httpx
Requires:       python-idna
Requires:       python-packaging
Requires:       python-pydantic
Requires:       python-wrapt
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A client library for accessing langfuse, an open-source LLM engineering platform that helps teams
collaboratively debug, analyze, and iterate on their LLM applications.

%prep
%autosetup -p1 -n langfuse-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/release
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative release

%postun
%python_uninstall_alternative release

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/release
%{python_sitelib}/langfuse
%{python_sitelib}/langfuse-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.54.1:
  * fix(media): allow setting IO media via decorator update
- update to 2.54.0:
  * feat(core): add multimodal support
  * fix(openai): pass parsed_n only if greater 1
- update to 2.53.9:
  * perf: move serialization to background threads
- update to 2.53.8:
  * fix(datasets): encoding
- update to 2.53.7:
  * fix(openai): revert default stream option setting
- update to 2.53.6:
  * fix(serializer): reduce log level to debug on failed
    serialization
- update to 2.53.5:
  * fix(serializer): pydantic compat v1 v2
- update to 2.53.4:
  * feat(openai): parse usage if stream_options has include_usage
- update to 2.53.3:
  * fix(datasets): url encode dataset name and run name
  * refactor(llama-index): send generation updates directly from
    event handler
- update to 2.53.2:
  * fix(llama-index): CompletionResponse Serialization by
    @hassiebp
- update to 2.53.1:
  * fix: 'NoneType' object has no attribute '__dict__'
- update to 2.53.0:
  * feat(client): allow masking event input and output by
    @shawnzhu and @hassiebp in
    https://github.com/langfuse/langfuse-python/pull/977
  * fix(decorator): improve stack access safety
- update to 2.52.2:
  * fix(openai): handle NoneType responses gracefully
  * docs(llama-index): deprecate CallbackHandler and promote
    Instrumentor
  * fix(langchain): DeepInfra model parsing
- update to 2.52.1:
  * fix(decorators): stack trace on failed auth_check
  * fix(api): list models parsing errors
  * fix(langchain): parse tool calls in input
- update to 2.52.0:
  * feat(llama-index): add LlamaIndexInstrumentor for use with
    instrumentation module instead of LlamaIndexSpanHandler
- update to 2.51.5:
  * fix(openai): structured output parsing with openai >= 1.50
  * chore(deps): bump django from 5.0.8 to 5.0.9 in
    /examples/django_example
- update to 2.51.4:
  * fix(serializer): Fix None serialization without langchain
    installed
  * fix(langchain): invalid user_id / session_id in TraceBody
  * chore(deps-dev): bump pytest from 8.2.0 to 8.3.3
  * chore: automerge dependabot patch PRs
  * chore(deps): bump pydantic from 2.7.4 to 2.9.2
  * chore: fix dependabot automerge
  * chore: fix auto merging
  * chore: fix auto merging
- update to 2.51.3:
  * fix(langchain): time to first token
- update to 2.51.2:
  * fix(prompts): remove traceback from fetch error logs
  * fix(langchain): parse model name for ChatOCIGenAIAgent
- update to 2.51.0:
  * feat(langchain): time to first token on streamed generations
  * feat(langchain): allow passing trace attributes on chain
    invocation
  * fix(langchain): python langchain retriever - parent run not
    found
  * fix handle_span_events exception
- update to 2.50.3:
  * fix(serializer): support numpy scalars
- update to 2.50.2:
  * feat(prompts): allow passing kwargs to precompile langchain
    prompt
- update to 2.50.1:
  * fix(langchain): link prompts to nested generations as well
- update to 2.50.0:
  * feat(decorator): allow setting parent trace or observation id
- update to 2.49.0:
  * feat(langchain): link langfuse prompts to langchain
    executions
- update to 2.48.1:
  * fix(openai): multiple streamed tool calls
  * fix(openai): time to first token
- update to 2.48.0:
  * feat(decorator): Enhance `observe` decorator to support usage
    without parentheses
  * fix(llama-index): initialize OpenAI model serializers
  * fix(langchain): ollama usage parsing
  * fix(langchain/AzureChatOpenai): unnecessary logs
  * fix(langchain): batch run to update trace outputs
- update to 2.47.1:
  * feat: improve error messages
- update to 2.47.0:
  * feat(prompts): optionally disable prompt caching when cache
    ttl is 0
  * Docs: https://langfuse.com/docs/prompts/get-started#disable-
    caching
* Thu Oct 31 2024 Matej Cepl <mcepl@cepl.eu>
- Add missing Requires.
* Fri Sep 27 2024 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 2.44.0
  changes since v2.43.1
  - fix: rename careers file to match hackernews post (#2115)
  - fix: link of help link of eval log
  - docs: careers file extension (#2105)
  - docs: Update .env.prod.example (#2103)
  - fix(ui): parse chatml messages where content is an array (#2100)
  - fix(ui): spacing of user menu
  - fix(ui): padding of second-level menu
  - feat(ui): less padding in main menu (#2095)
  - fix(api): merge tags when upserting a trace (#2091)
  - fix: set cache control explicitly (#2088)
  - fix(cloud): remove custom cookie management (#2087)
  - chore: adjust sentry (#2086)
  - feat(cloud): include data region in project invite emails
  - feat(auth): improve auth error messages and logging
  - fix(ui): use `svh` for fullscreen pages on mobile (#2076)
  - feat(auth): capture unexpected credential sign-in errors
  - feat(cloud): data region select and info modal (#2085)
  - intercept OpenAI requests in worker testruns (#2020)
  - fix(api): align get/v2/prompts meta response with api spec (#2079)
* Wed Aug 21 2024 Aline Werner <aline.werner@suse.com>
- Fix executable file conflict for Tumbleweed build, change description and add missing URL.
* Fri Aug  9 2024 Aline Werner <aline.werner@suse.com>
- Initial package creation for python-langfuse version 2.43.1
